import path from 'path';

export default function ({ types: t }) {
  return {
    visitor: {
      CallExpression({ node }, { opts, file }) {
        if (node.callee.name !== 'require' || node.arguments.length !== 1 ||
          !t.isStringLiteral(node.arguments[0])) return;
        const { value } = node.arguments[0];
        const { ignore = [], baseDir = '' } = opts;
        if (value.startsWith('.') || ignore.includes(value)) return;
        try {
          require(value); // eslint-disable-line
        } catch (e) {
          if (e.message.startsWith('Cannot find module')) {
            const { filename } = file.opts;
            node.arguments[0].value = './' + path.relative(filename ? path.dirname(filename) : __dirname, path.resolve(baseDir, value)); // eslint-disable-line
          }
        }
      },
    },
  };
}
